@@ -37,15 +37,7 @@ get_package_makelist <- function(is_cran = FALSE, gitlab_token = NULL) {
     ml <- fat(makelist = ml, 
                      target = file.path("log", "vignettes.Rout"),
                      code = paste0("devtools::build_vignettes(); ", 
-                                   "dir.create(file.path(\"inst\", \"doc\")); ", 
-                                   "lapply(tools::pkgVignettes(dir = \".\")", 
-                                   "[[\"docs\"]], ", 
-                                   "function(x) knitr::purl(x, ", 
-                                   "output = file.path(\".\", \"inst\", ",
-                                   "\"doc\", ", 
-                                   "sub(\"\\\\.[Rr]md$$\", \".R\", ",
-                                   "basename(x))), ",
-                                   "documentation = 0))"),
+                                   "packager::extract_vignette_codes()"),
                      prerequisites =  c(list_files("R"), list_files("tests"), 
                                         list_files("vignettes")),
                      prerequisite_to = build_target)
